#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wcwidth
version:              0.0.2
visibility:           public
id:                   wcwidth-0.0.2-2Wour6vTJTs8dTSlv8oqfV
key:                  wcwidth-0.0.2-2Wour6vTJTs8dTSlv8oqfV
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/wcwidth/
synopsis:             Native wcwidth.
description:
    Bindings for your system'\''s native wcwidth and a command line tool to examine
    the widths assigned by it. The command line tool can compile a width table
    to Haskell code that assigns widths to the Char type.

category:             Text
abi:                  0dd9ecef8505e5eabb7302950fc2ab26
exposed:              True
exposed-modules:      Data.Char.WCWidth
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wcwidth-0.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wcwidth-0.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wcwidth-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wcwidth
hs-libraries:         HSwcwidth-0.0.2-2Wour6vTJTs8dTSlv8oqfV
depends:              base-4.18.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-wcwidth/html/wcwidth.haddock
haddock-html:         /usr/share/doc/haskell-wcwidth/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

